<?php namespace Concrete\Package\ExitIntent\Block\ExitIntent;
use Concrete\Core\Block\BlockController;
use Concrete\Core\Support\Facade\Application;
use Concrete\Core\File\File; 
use Concrete\Core\Page\Page;
use Core;
use StackList;
use Stack;

class Controller extends BlockController
{
    protected $btTable = 'btExitIntent';
    protected $btInterfaceWidth = "560";
	protected $btInterfaceHeight = "400";
    protected $btWrapperClass = 'ccm-ui';
	protected $btDefaultSet = 'marketing';
	public $fID = "";

    public function getBlockTypeDescription(){
        return t("Display a popup message when the user tries to leave a page.");
    }

    public function getBlockTypeName(){
        return t("Exit Intent");
    }
	
	protected function getStackNames() {
		$stackList = array();
		$stm = new StackList();
		$stm->filterByUserAdded(); 
		$stacks = $stm->get();

		if($stacks) {
		foreach($stacks as $st) {
			$name = $st->getCollectionName();
			$stackNames[] = $name;
		}
		asort($stackNames);
		return $stackNames;
		}
    }
	
	public function add() { $this->edit(); }
	public function edit() {
		$this->set('app', Application::getFacadeApplication());
		// Get all stacks.
		$stacks = $this->getStackNames();
        $stackList = array('' => t('None'));
        $txt = Core::make('helper/text');
        if($stacks) {
			foreach($stacks as $st) {
				$stackList[$st] = $txt->unhandle($st);
			}
        }
        $this->set('stackList', $stackList);
	}

	public function registerViewAssets($outputContent = '') {
        $this->requireAsset('javascript', 'jquery');
    }
	public function getFileID() {
        return $this->fID;
    }
	public function getFileObject() {
        return File::getByID($this->fID);
    }
	function getExternalLink() {return $this->externalLink;}
	function getInternalLinkCID() {return $this->internalLinkCID;}
	function getLinkURL() {
		if (!empty($this->externalLink)) {
			return $this->externalLink;
		} else if (!empty($this->internalLinkCID)) {
			$linkToC = Page::getByID($this->internalLinkCID);
			return (empty($linkToC) || $linkToC->error) ? '' : $this->app->make('helper/navigation')->getLinkToCollection($linkToC);
		} else {
			return '';
		}
	}
	public function on_start() {
		if(!is_object($this->app)){
			$this->app = \Concrete\Core\Support\Facade\Application::getFacadeApplication();
			$this->set('app', $this->app);
		}
	}

	public function validate($args) {
        if (!is_object($this->app)) {
            $app = Application::getFacadeApplication();
        } else {
            $app = $this->app;
        }
		$e = $app->make('error');

		if(!ctype_digit(trim($args['delayregister']))){
            $e->add(t("Register delay must be numeric only."));
        }
		if(!ctype_digit(trim($args['delayshow']))){
            $e->add(t("Delay must be numeric only."));
        }
		if(!ctype_digit(trim($args['mobileshowafter']))){
            $e->add(t("Mobile delay must be numeric only."));
        }
		if(!ctype_digit(trim($args['bwidth']))){
            $e->add(t("Border width must be numeric only."));
        }
		if(empty($args['popwidth'])){
            $e->add(t("Popup width is required!"));
        }
		if(!ctype_digit(trim($args['popwidth']))){
            $e->add(t("Popup width must be numeric only."));
        }
		if(empty($args['maxwidth'])){
            $e->add(t("Maximum width is required!"));
        }
		if(!ctype_digit(trim($args['maxwidth']))){
            $e->add(t("Maximum width must be numeric only."));
        }
		if($args['contentType']=="img"){
			if(empty($args['fID'])){
				$e->add(t("Image is required."));
			} elseif (!empty($args['fID'])) {
				$f = File::getByID($args['fID']); // Get the file	
				$fv = $f->getVersion();  // Get the file version
				$fileType = strtolower($fv->getExtension());  // Get the file extension
				$ftypes = array("jpg","jpeg","png","gif"); // Define array of file types.
				if(!in_array($fileType, $ftypes)) {   // If the file extension is NOT in the array, return this error.
					$e->add(t("Invalid image type. Please select a GIF, JPG, or PNG file."));
				}
			}
		}
		return $e;
    }
	
	public function save($data) { 
		switch (intval($data['linkType'])) {
			case 1:
				$data['externalLink'] = '';
				break;
			case 2:
				$data['internalLinkCID'] = 0;
				break;
			default:
				$data['externalLink'] = '';
				$data['internalLinkCID'] = 0;
				break;
		}
		unset($data['linkType']);
		parent::save($data);
	}

}